@@ -89,6 +89,13 @@ UNSORTED_GROUPS_TESTING = [
       {"group1": "3", "group2": "1", "value": 1},
       {"group1": "1", "group2": "1", "value": 1},
       ]),
+
+    # IGNORE LIMIT BY AND SHOW OTHER WITHOUT LIMIT
+    ({"aggregation": "count", "groupBy": "group1",
+      "limitBy": "group1", "showOther": 1},
+     [{"group1": "1", "value": 2},
+      {"group1": "2", "value": 1},
+      {"group1": "3", "value": 3}]),
 ]
 
 SORTED_GROUPS_TESTING = [
@@ -177,4 +184,14 @@ SORTED_GROUPS_TESTING = [
       {"date__trunc__day": date(2020, 10, 31), "value": 1},
       {"date__trunc__day": date(2020, 11, 1), "value": 2},
       {"date__trunc__day": date(2020, 11, 2), "value": 1}]),
+
+    # AGGREGATION ON EMPTY QUERY
+    ({"search": "4", "aggregation": "count", "groupBy": "group1"},
+     []),
+
+    # AGGREGATION ON EMPTY QUERY WITH SORT BY TOTAL GROUP VALUE
+    ({"search": "4", "columnIndex": "group1",
+      "aggregation": "count",
+      "groupBy": "group1,group2", "orderBy": "-group1__index,-group2"},
+     []),
 ]
